@@ -29,32 +29,25 @@ from typing import Any
 from pydantic import BaseModel, Field
 
 from arklex.memory.entities.memory_entities import ResourceRecord
-from arklex.types.stream_types import StreamType
-from arklex.utils.llm_config import LLMConfig
+from arklex.models.llm_config import LLMConfig
+from arklex.orchestrator.types.stream_types import StreamType
 
 
 # Bot-related classes
 class BotConfig(BaseModel):
-    """Configuration for bot settings.
+    """Configuration for settings.
 
-    This class defines the overall configuration for a bot instance, including its
-    identity, version, language settings, and language model configuration.
+    This class defines the overall configuration for a bot instance, including its language settings and language model configuration.
 
     The class provides:
-    1. Bot identity and versioning
-    2. Language and settings
-    3. LLM configuration integration
-    4. Type-safe configuration management
+    1. Language
+    2. LLM configuration
 
     Attributes:
-        bot_id (str): Unique identifier for the bot.
-        version (str): Version number of the bot.
         language (str): Primary language of the bot.
         llm_config (LLMConfig): Language model configuration for the bot.
     """
 
-    bot_id: str = Field(default="")
-    version: str = Field(default="")
     language: str = Field(default="EN")
     llm_config: LLMConfig = Field(default_factory=LLMConfig)
 
@@ -76,8 +69,10 @@ class ConvoMessage(BaseModel):
         message (str): The current message content.
     """
 
-    history: str  # it could be the whole original message or the summarization of the previous conversation from memory module
     message: str
+    history: str = Field(
+        default=""
+    )  # it could be the whole original message or the summarization of the previous conversation from memory module
 
 
 ### Task status-related classes
@@ -115,10 +110,10 @@ class Timing(BaseModel):
     3. Type-safe timing management
 
     Attributes:
-        taskgraph (Optional[float]): Time taken for task graph processing.
+        nlugraph (Optional[float]): Time taken for nlu graph processing.
     """
 
-    taskgraph: float | None = None
+    nlugraph: float | None = None
 
 
 class Metadata(BaseModel):
@@ -214,6 +209,7 @@ class OrchestratorState(BaseModel):
     message_flow: str = Field(default="")
     # record history
     function_calling_trajectory: list[dict[str, Any]] | None = Field(default=None)
+    openai_agents_trajectory: list[dict[str, Any]] | None = Field(default=None)
     trajectory: list[list[ResourceRecord]] | None = Field(default=None)
     relevant_records: list[ResourceRecord] | None = Field(default=None)
     # streaming
