@@ -10,8 +10,12 @@ from unittest.mock import Mock, patch
 import pytest
 import requests
 
-from arklex.env.tools.custom_tools.http_tool import http_tool, replace_placeholders
-from arklex.utils.exceptions import ToolExecutionError
+from arklex.orchestrator.nlu.entities.slot_entities import Slot
+from arklex.resources.tools.custom_tools.http_tool import (
+    http_tool,
+    replace_placeholders,
+)
+from arklex.utils.logging.exceptions import ToolExecutionError
 
 
 class TestReplacePlaceholders:
@@ -236,8 +240,8 @@ class TestHTTPTool:
         mock_request.return_value = mock_response
 
         slots = [
-            {"name": "user_id", "value": 123, "target": "params"},
-            {"name": "user_name", "value": "John", "target": "body"},
+            Slot(name="user_id", value=123, target="params"),
+            Slot(name="user_name", value="John", target="body"),
         ]
 
         result = http_tool.func(
@@ -265,17 +269,9 @@ class TestHTTPTool:
         mock_response.raise_for_status.return_value = None
         mock_request.return_value = mock_response
 
-        class SlotObject:
-            def __init__(
-                self, name: str, value: str | int | bool | None, target: str
-            ) -> None:
-                self.name = name
-                self.value = value
-                self.target = target
-
         slots = [
-            SlotObject("user_id", 123, "params"),
-            SlotObject("user_name", "John", "body"),
+            Slot(name="user_id", value=123, target="params"),
+            Slot(name="user_name", value="John", target="body"),
         ]
 
         result = http_tool.func(
@@ -303,17 +299,9 @@ class TestHTTPTool:
         mock_response.raise_for_status.return_value = None
         mock_request.return_value = mock_response
 
-        class SlotObject:
-            def __init__(
-                self, name: str, value: str | int | bool | None, target: str
-            ) -> None:
-                self.name = name
-                self.value = value
-                self.target = target
-
         slots = [
-            {"name": "user_id", "value": 123, "target": "params"},
-            SlotObject("user_name", "John", "body"),
+            Slot(name="user_id", value=123, target="params", type="int"),
+            Slot(name="user_name", value="John", target="body", type="str"),
         ]
 
         result = http_tool.func(
@@ -333,35 +321,6 @@ class TestHTTPTool:
         assert call_args[1]["params"]["user_id"] == 123
         assert call_args[1]["json"]["name"] == "John"
 
-    @patch("requests.request")
-    def test_http_tool_with_invalid_slots(self, mock_request: Mock) -> None:
-        """Test HTTP tool with invalid slot structure."""
-        mock_response = Mock()
-        mock_response.json.return_value = {"status": "success"}
-        mock_response.raise_for_status.return_value = None
-        mock_request.return_value = mock_response
-
-        # Slots with missing required attributes
-        slots = [
-            {"name": "user_id"},  # Missing value and target
-            {"value": "John"},  # Missing name and target
-        ]
-
-        result = http_tool.func(
-            node_specific_data={
-                "method": "POST",
-                "endpoint": "https://api.example.com/users",
-                "headers": {"Content-Type": "application/json"},
-                "body": {},
-                "params": {},
-            },
-            slots=slots,
-        )
-
-        # Should still work without the invalid slots
-        assert "success" in result
-        mock_request.assert_called_once()
-
     @patch("requests.request")
     def test_http_tool_with_none_slots(self, mock_request: Mock) -> None:
         """Test HTTP tool with None slots parameter."""
@@ -459,88 +418,6 @@ class TestHTTPTool:
         assert "success" in result
         mock_request.assert_called_once()
 
-    @patch("requests.request")
-    def test_http_tool_with_slot_missing_attributes(self, mock_request: Mock) -> None:
-        """Test HTTP tool with slots missing required attributes."""
-        mock_response = Mock()
-        mock_response.json.return_value = {"status": "success"}
-        mock_response.raise_for_status.return_value = None
-        mock_request.return_value = mock_response
-
-        # Slots with missing attributes
-        slots = [
-            {"name": "user_id", "value": 123},  # Missing target
-            {"value": "John", "target": "body"},  # Missing name
-            {"name": "user_name", "target": "body"},  # Missing value
-        ]
-
-        result = http_tool.func(
-            node_specific_data={
-                "method": "POST",
-                "endpoint": "https://api.example.com/test",
-                "headers": {"Content-Type": "application/json"},
-                "body": {},
-                "params": {},
-            },
-            slots=slots,
-        )
-
-        assert "success" in result
-        mock_request.assert_called_once()
-
-    @patch("requests.request")
-    def test_http_tool_with_slot_object_missing_attributes(
-        self, mock_request: Mock
-    ) -> None:
-        """Test HTTP tool with slot object missing attributes."""
-        mock_response = Mock()
-        mock_response.json.return_value = {"ok": True}
-        mock_response.raise_for_status.return_value = None
-        mock_request.return_value = mock_response
-
-        class SlotObj:
-            pass  # No name, value, or target
-
-        slots = [SlotObj()]
-        result = http_tool.func(
-            node_specific_data={
-                "method": "GET",
-                "endpoint": "http://x",
-                "headers": {},
-                "body": {},
-                "params": {},
-            },
-            slots=slots,
-        )
-        assert "ok" in result
-
-    @patch("requests.request")
-    def test_http_tool_with_slot_object_none_name(self, mock_request: Mock) -> None:
-        """Test HTTP tool with slot object having None name."""
-        mock_response = Mock()
-        mock_response.json.return_value = {"ok": True}
-        mock_response.raise_for_status.return_value = None
-        mock_request.return_value = mock_response
-
-        class SlotObj:
-            def __init__(self) -> None:
-                self.name = None
-                self.value = "test"
-                self.target = "body"
-
-        slots = [SlotObj()]
-        result = http_tool.func(
-            node_specific_data={
-                "method": "GET",
-                "endpoint": "http://x",
-                "headers": {},
-                "body": {},
-                "params": {},
-            },
-            slots=slots,
-        )
-        assert "ok" in result
-
     @patch("requests.request")
     def test_http_tool_remove_placeholders_and_valid_json(
         self, mock_request: Mock
@@ -701,7 +578,7 @@ class TestHTTPToolDataCleaning:
 
     def test_clean_json_data_nested_dict(self) -> None:
         """Test cleaning nested dictionary data."""
-        from arklex.env.tools.custom_tools.http_tool import clean_json_data
+        from arklex.resources.tools.custom_tools.http_tool import clean_json_data
 
         data = {
             "level1": {
@@ -724,7 +601,7 @@ class TestHTTPToolDataCleaning:
 
     def test_clean_json_data_non_dict_input(self) -> None:
         """Test clean_json_data with non-dict input."""
-        from arklex.env.tools.custom_tools.http_tool import clean_json_data
+        from arklex.resources.tools.custom_tools.http_tool import clean_json_data
 
         # Should return input as-is for non-dict types
         assert clean_json_data("string") == "string"
@@ -734,14 +611,14 @@ class TestHTTPToolDataCleaning:
 
     def test_clean_json_data_empty_dict(self) -> None:
         """Test clean_json_data with empty dictionary."""
-        from arklex.env.tools.custom_tools.http_tool import clean_json_data
+        from arklex.resources.tools.custom_tools.http_tool import clean_json_data
 
         result = clean_json_data({})
         assert result == {}
 
     def test_clean_json_data_with_list_values(self) -> None:
         """Test clean_json_data with list values containing placeholders."""
-        from arklex.env.tools.custom_tools.http_tool import clean_json_data
+        from arklex.resources.tools.custom_tools.http_tool import clean_json_data
 
         data = {
             "items": [
@@ -758,7 +635,7 @@ class TestHTTPToolDataCleaning:
 
     def test_validate_request_body_success(self) -> None:
         """Test validate_request_body with valid data."""
-        from arklex.env.tools.custom_tools.http_tool import validate_request_body
+        from arklex.resources.tools.custom_tools.http_tool import validate_request_body
 
         body = {"name": "test", "age": 30, "active": True}
 
@@ -767,7 +644,7 @@ class TestHTTPToolDataCleaning:
 
     def test_validate_request_body_with_placeholders(self) -> None:
         """Test validate_request_body with placeholders."""
-        from arklex.env.tools.custom_tools.http_tool import validate_request_body
+        from arklex.resources.tools.custom_tools.http_tool import validate_request_body
 
         body = {"name": "{{user_name}}", "age": "{{user_age}}", "normal": "value"}
 
@@ -778,14 +655,14 @@ class TestHTTPToolDataCleaning:
 
     def test_validate_request_body_none_input(self) -> None:
         """Test validate_request_body with None input."""
-        from arklex.env.tools.custom_tools.http_tool import validate_request_body
+        from arklex.resources.tools.custom_tools.http_tool import validate_request_body
 
         result = validate_request_body(None)
         assert result is None
 
     def test_validate_request_body_invalid_json(self) -> None:
         """Test validate_request_body with data that can't be JSON serialized."""
-        from arklex.env.tools.custom_tools.http_tool import validate_request_body
+        from arklex.resources.tools.custom_tools.http_tool import validate_request_body
 
         # Create an object that can't be JSON serialized
         class NonSerializable:
